@@ -19,7 +19,6 @@ import time
 import warnings
 import click
 import inspect
-import alacorder as alac
 from alacorder import get 
 from alacorder import write 
 from alacorder import config 
@@ -30,22 +29,24 @@ try:
     import xlsxwriter
 except ImportError:
     pass
-def table(conf, table=""):
+def table(conf):
     """
     Route config to parse...() function corresponding to table attr 
     """
     a = []
+    #print(conf['TABLE'])
+    #print(conf.TABLE)
     if conf.MAKE == "multiexport":
         a = cases(conf)
-    if table == "cases":
+    if conf['TABLE'] == "cases":
         a = caseinfo(conf)
-    if table == "fees":
+    if conf['TABLE'] == "fees":
         a = fees(conf)
-    if table == "charges":
+    if conf['TABLE'] == "charges":
         a = charges(conf)
-    if table == "disposition":
+    if conf['TABLE'] == "disposition":
         a = charges(conf)
-    if table == "filing":
+    if conf['TABLE'] == "filing":
         a = charges(conf)
     return a
 
@@ -59,7 +60,7 @@ def fees(conf):
     path_in = conf['INPUT_PATH']
     path_out = conf['OUTPUT_PATH']
     out_ext = conf['OUTPUT_EXT']
-    max_cases = conf['COUNT']
+    count = conf['COUNT']
     queue = conf['QUEUE']
     print_log = conf['LOG']
     warn = conf['WARN']
@@ -69,10 +70,10 @@ def fees(conf):
     start_time = time.time()
     if warn == False:
         warnings.filterwarnings("ignore")
-    outputs = pd.DataFrame()
-    fees = pd.DataFrame({'CaseNumber': '', 
-        'Code': '', 'Payor': '', 'AmtDue': '', 
-        'AmtPaid': '', 'Balance': '', 'AmtHold': ''},index=[0])
+    fees = pd.DataFrame()
+    # fees = pd.DataFrame({'CaseNumber': '', 
+      #  'Code': '', 'Payor': '', 'AmtDue': '', 
+       # 'AmtPaid': '', 'Balance': '', 'AmtHold': ''},index=[0])
     if not conf['NO_BATCH']:
         batches = config.batcher(conf)
     else:
@@ -91,19 +92,19 @@ def fees(conf):
 
             b['caseinfoOutputs'] = b['AllPagesText'].map(lambda x: get.CaseInfo(x))
             b['CaseNumber'] = b['caseinfoOutputs'].map(lambda x: x[0])
-            try:
-                b['FeeOutputs'] = b.index.map(lambda x: get.FeeSheet(str(b.loc[x].AllPagesText)))
-                feesheet = b['FeeOutputs'].map(lambda x: x[6]) 
-            except (AttributeError,IndexError):
-                pass
+            #try:
+            b['FeeOutputs'] = b.index.map(lambda x: get.FeeSheet(str(b.loc[x].AllPagesText)))
+            feesheet = b['FeeOutputs'].map(lambda x: x[6]) 
+            #except (AttributeError,IndexError):
+             #   pass
 
             feesheet = feesheet.dropna() # drop empty 
             fees =fees.dropna()
             feesheet = feesheet.tolist() # convert to list -> [df, df, df]
-            try:
-                feesheet = pd.concat(feesheet,axis=0,ignore_index=True) # add all dfs in batch -> df
-            except ValueError:
-                pass
+            #try:
+            feesheet = pd.concat(feesheet,axis=0,ignore_index=True) # add all dfs in batch -> df
+            #except ValueError:
+             #   pass
             fees = fees.append(feesheet, ignore_index=True) 
             fees.fillna('',inplace=True)
             fees['AmtDue'] = fees['AmtDue'].map(lambda x: pd.to_numeric(x,'coerce'))
@@ -122,7 +123,7 @@ def charges(conf):
     path_in = conf['INPUT_PATH']
     path_out = conf['OUTPUT_PATH']
     out_ext = conf['OUTPUT_EXT']
-    max_cases = conf['COUNT']
+    count = conf['COUNT']
     queue = conf['QUEUE']
     print_log = conf['LOG']
     warn = conf['WARN']
@@ -142,7 +143,6 @@ def charges(conf):
     batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
 
     start_time = time.time()
-    outputs = pd.DataFrame()
     charges = pd.DataFrame()
     with click.progressbar(batches) as bar:
         for i, c in enumerate(bar):
@@ -165,15 +165,15 @@ def charges(conf):
             charges = charges.append(chargetabs)
             charges.fillna('',inplace=True)
 
-            if table == "filing":
-                is_disp = charges['Disposition']
-                is_filing = is_disp.map(lambda x: False if x == True else True)
-                charges = charges[is_filing]
-                charges.drop(columns=['CourtAction','CourtActionDate'],inplace=True)
+        if table == "filing":
+            is_disp = charges['Disposition']
+            is_filing = is_disp.map(lambda x: False if x == True else True)
+            charges = charges[is_filing]
+            charges.drop(columns=['CourtAction','CourtActionDate'],inplace=True)
 
-            if table == "disposition":
-                is_disp = charges.Disposition.map(lambda x: True if x == True else False)
-                charges = charges[is_disp]
+        if table == "disposition":
+            is_disp = charges.Disposition.map(lambda x: True if x == True else False)
+            charges = charges[is_disp]
         if not no_write:
             write.now(conf, charges)
 
@@ -187,20 +187,22 @@ def cases(conf):
     path_in = conf['INPUT_PATH']
     path_out = conf['OUTPUT_PATH']
     out_ext = conf['OUTPUT_EXT']
-    max_cases = conf['COUNT']
+    count = conf['COUNT']
     queue = conf['QUEUE']
     print_log = conf['LOG']
     warn = conf['WARN']
     no_write = conf['NO_WRITE']
     dedupe = conf['DEDUPE']
     table = conf['TABLE']
-    dedupe = conf['DEDUPE']
+    overwrite = conf['OVERWRITE']
     path_out = conf['OUTPUT_PATH'] if conf.MAKE != "archive" else ''
     archive_out = conf['OUTPUT_PATH'] if conf.MAKE == "archive" else ''
     from_archive = True if conf['IS_FULL_TEXT'] else False
     start_time = time.time()
     arc_ext = conf['OUTPUT_EXT']
     cases = pd.DataFrame()
+    fees = pd.DataFrame()
+    charges = pd.DataFrame()
     if not conf['NO_BATCH']:
         batches = config.batcher(conf)
     else:
@@ -251,34 +253,34 @@ def cases(conf):
             b['FeeCodesOwed'] = b['FeeOutputs'].map(lambda x: x[3])
             b['FeeCodes'] = b['FeeOutputs'].map(lambda x: x[4])
             b['FeeSheet'] = b['FeeOutputs'].map(lambda x: x[5])
-
+            logs.debug(conf, b['FeeSheet'])
 
             feesheet = b['FeeOutputs'].map(lambda x: x[6]) 
             feesheet = feesheet.dropna() 
             feesheet = feesheet.tolist() # -> [df, df, df]
             
-            try:
-                feesheet = pd.concat(feesheet,axis=0,ignore_index=True) #  -> batch df
-            except:
-                pass
-            try:
-                fees = fees.append(feesheet, ignore_index=True) # -> all fees df
-            except:
-                pass
-
+            #try:
+            feesheet = pd.concat(feesheet,axis=0,ignore_index=True) #  -> batch df
+            #except:
+             #   pass
+            #try:
+            fees = fees.append(feesheet)
+            #except:
+             #   pass
+            logs.debug(conf, fees)
             chargetabs = b['chargesOutputs'].map(lambda x: x[17])
             chargetabs = chargetabs.dropna()
             # charges = charges.dropna()
             chargetabs = chargetabs.tolist()
             
-            try:
-                chargetabs = pd.concat(chargetabs,axis=0,ignore_index=True)
-            except:
-                pass
-            try:
-                charges = charges.append(chargetabs,ignore_index=True)
-            except:
-                pass
+            #try:
+            chargetabs = pd.concat(chargetabs,axis=0,ignore_index=True)
+            #except:
+             #   pass
+            #try:
+            charges = charges.append(chargetabs,ignore_index=True)
+            #except:
+             #   pass
             
             feesheet['AmtDue'] = feesheet['AmtDue'].map(lambda x: pd.to_numeric(x,'coerce'))
             feesheet['AmtPaid'] = feesheet['AmtPaid'].map(lambda x: pd.to_numeric(x,'coerce'))
@@ -325,9 +327,6 @@ def cases(conf):
             b.fillna('',inplace=True)
             newcases = [cases, b]
             cases = cases.append(newcases, ignore_index=True)
-            # charges = charges[['CaseNumber', 'Num', 'Code', 'Description', 'Cite', 'CourtAction', 'CourtActionDate', 'Category', 'TypeDescription', 'Disposition', 'Permanent', 'Pardon', 'CERV','Conviction']]
-            # fees = fees[['CaseNumber', 'FeeStatus', 'AdminFee','Total', 'Code', 'Payor', 'AmtDue', 'AmtPaid', 'Balance', 'AmtHold']]
-            
 
             if no_write == False and temp_no_write_tab == False and (i % 5 == 0 or i == len(batches) - 1):
                 if out_ext == ".xls":
@@ -359,7 +358,7 @@ def cases(conf):
                         except (ImportError, FileNotFoundError, IndexError, ValueError, ModuleNotFoundError):
                             try:
                                 try:
-                                    if not appendtable:
+                                    if overwrite:
                                         os.remove(path_out)
                                 except:
                                     pass
@@ -385,15 +384,15 @@ def cases(conf):
                 elif out_ext == ".parquet":
                     outputs.to_parquet(path_out)
                 else:
-                    pd.Series([cases, fees, charges]).to_string(path_out)
+                    pd.Series([cases, feesheet, chargetabs]).to_string(path_out)
                 try:
                     if dedupe == True and outputs.shape[0] < queue.shape[0]:
                         click.echo(f"Identified and removed {outputs.shape[0]-queue.shape[0]} from queue.")
                 except:
                     pass
 
-        logs.complete(conf, start_time, pd.Series([cases, fees, charges]).to_string())
-        return [cases, fees, charges]
+        logs.complete(conf, start_time, pd.Series([cases, feesheet, chargetabs]).to_string())
+        return [cases, feesheet, chargetabs]
 
 def caseinfo(conf):
     """
@@ -403,7 +402,7 @@ def caseinfo(conf):
     path_in = conf['INPUT_PATH']
     path_out = conf['OUTPUT_PATH']
     out_ext = conf['OUTPUT_EXT']
-    max_cases = conf['COUNT']
+    count = conf['COUNT']
     queue = conf['QUEUE']
     print_log = conf['LOG']
     warn = conf['WARN']
@@ -422,7 +421,7 @@ def caseinfo(conf):
     else:
         batches = np.array_split(queue, 1)
     batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
-    
+    logs.debug(conf, [batches,batchsize])
     
 
     if warn == False:
@@ -436,6 +435,7 @@ def caseinfo(conf):
                 b['AllPagesText'] = pd.Series(c).map(lambda x: get.PDFText(x))
 
             b['caseinfoOutputs'] = b['AllPagesText'].map(lambda x: get.CaseInfo(x))
+            logs.debug(conf, b['caseinfoOutputs'])
             b['CaseNumber'] = b['caseinfoOutputs'].map(lambda x: x[0])
             b['Name'] = b['caseinfoOutputs'].map(lambda x: x[1])
             b['Alias'] = b['caseinfoOutputs'].map(lambda x: x[2])
@@ -485,10 +485,11 @@ def map(conf, *args):
     Creates DataFrame with column for each getter column output and row for each case in queue
 
     """
+    logs.debug(conf,conf)
     path_in = conf['INPUT_PATH']
     path_out = conf['OUTPUT_PATH']
     out_ext = conf['OUTPUT_EXT']
-    max_cases = conf['COUNT']
+    count = conf['COUNT']
     queue = conf['QUEUE']
     print_log = conf['LOG']
     warn = conf['WARN']
@@ -506,7 +507,7 @@ def map(conf, *args):
     else:
         batches = np.array_split(queue, 1)
     batchsize = max(pd.Series(batches).map(lambda x: x.shape[0]))
-
+    logs.debug(conf, [batches, batchsize])
     start_time = time.time()
     alloutputs = []
     uselist = False
@@ -573,7 +574,7 @@ def map(conf, *args):
                 df_out = pd.concat([df_out,col.reindex(df_out.index)],axis=1)
                 df_out = df_out.dropna(axis=1)
                 df_out = df_out.convert_dtypes()
-
+                logs.debug(conf, df_out)
             if no_write == False and temp_no_write_tab == False and (i % 5 == 0 or i == len(batches) - 1):
                 write.now(conf, df_out) # rem alac
     if not no_write:
