@@ -6,29 +6,18 @@ import sys
 import glob
 import re
 import math
-import numexpr
 import xarray
-import bottleneck
 import numpy as np
-import xlrd
-import openpyxl
 import datetime
 import pandas as pd
 import time
 import warnings
 import click
 import inspect
-import alacorder as alac
 from alacorder import get 
 from alacorder import parse 
 from alacorder import config 
 from alacorder import logs
-import PyPDF2
-from io import StringIO
-try:
-    import xlsxwriter
-except ImportError:
-    pass
 
 def now(conf, outputs, archive=False):
     """
@@ -38,7 +27,7 @@ def now(conf, outputs, archive=False):
     path_out = conf['OUTPUT_PATH']
     arc_out = conf['OUTPUT_PATH']
     out_ext = conf['OUTPUT_EXT']
-    max_cases = conf['COUNT']
+    count = conf['COUNT']
     queue = conf['QUEUE']
     print_log = conf['LOG']
     warn = conf['WARN']
@@ -51,8 +40,6 @@ def now(conf, outputs, archive=False):
     archive_out = conf['OUTPUT_PATH'] if conf['MAKE'] == "archive" else ''
     from_archive = True if conf['IS_FULL_TEXT']==True else False
 
-
-
     try:
         out_ext = os.path.splitext(path_out)[1]
     except TypeError:
@@ -117,7 +104,7 @@ def archive(conf,parquet_test=False):
     path_out = conf['OUTPUT_PATH']
     arc_out = conf['OUTPUT_PATH']
     out_ext = conf['OUTPUT_EXT']
-    max_cases = conf['COUNT']
+    count = conf['COUNT']
     queue = conf['QUEUE']
     print_log = conf['LOG']
     warn = conf['WARN']
@@ -144,7 +131,6 @@ def archive(conf,parquet_test=False):
         'Timestamp': start_time,
         })
 
-
     outputs.fillna('',inplace=True)
 
     if not no_write and not parquet_test:
